/*
secure_control_protocol
ScpResponseRename Class
SPDX-License-Identifier: GPL-3.0-only
Copyright (C) 2020 Benjamin Schilling
*/

// Standard Library
import 'dart:convert';

// SCP
import 'package:secure_control_protocol/scp_crypto.dart';

class ScpResponseRename {
  static const String type = "security-rename";
  String deviceId;
  String result;

  ScpResponseRename({this.deviceId, this.result});

  static Future<ScpResponseRename> fromJson(
      var inputJson, String password) async {
    if (inputJson['response'] == null ||
        inputJson['response'] == '' ||
        inputJson['hmac'] == null ||
        inputJson['hmac'] == '') {
      return null;
    }
    String response = inputJson['response'];
    String hmac = inputJson['hmac'];

    // Check hmac before additional processing
    if (ScpCrypto().verifyHMAC(response, hmac, password)) {
      var decodedPayload = base64Decode(response);
      var decodedJson = json.decode(utf8.decode(decodedPayload));
      if (decodedJson['type'] == type) {
        ScpResponseRename renameResponse = ScpResponseRename(
          deviceId: decodedJson['deviceId'],
          result: decodedJson['result'],
        );
        return renameResponse;
      }
    }
    return null;
  }
}
